==> aws-cdk-scala_2.13-0.5.1-sources.jar: io/burkard/cdk/services/dms/cfnEndpoint/KafkaSettingsProperty.scala <==
package io.burkard.cdk.services.dms.cfnEndpoint

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object KafkaSettingsProperty {

  def apply(
    includeControlDetails: Option[Boolean] = None,
    includeTableAlterOperations: Option[Boolean] = None,
    noHexPrefix: Option[Boolean] = None,
    sslClientKeyArn: Option[String] = None,
    sslClientKeyPassword: Option[String] = None,
    sslCaCertificateArn: Option[String] = None,
    broker: Option[String] = None,
    securityProtocol: Option[String] = None,
    partitionIncludeSchemaTable: Option[Boolean] = None,
    includeNullAndEmpty: Option[Boolean] = None,
    includeTransactionDetails: Option[Boolean] = None,
    topic: Option[String] = None,
    sslClientCertificateArn: Option[String] = None,
    saslPassword: Option[String] = None,
    saslUserName: Option[String] = None
  ): software.amazon.awscdk.services.dms.CfnEndpoint.KafkaSettingsProperty =
    (new software.amazon.awscdk.services.dms.CfnEndpoint.KafkaSettingsProperty.Builder)
      .includeControlDetails(includeControlDetails.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .includeTableAlterOperations(includeTableAlterOperations.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .noHexPrefix(noHexPrefix.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .sslClientKeyArn(sslClientKeyArn.orNull)
      .sslClientKeyPassword(sslClientKeyPassword.orNull)
      .sslCaCertificateArn(sslCaCertificateArn.orNull)
      .broker(broker.orNull)
      .securityProtocol(securityProtocol.orNull)
      .partitionIncludeSchemaTable(partitionIncludeSchemaTable.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .includeNullAndEmpty(includeNullAndEmpty.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .includeTransactionDetails(includeTransactionDetails.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .topic(topic.orNull)
      .sslClientCertificateArn(sslClientCertificateArn.orNull)
      .saslPassword(saslPassword.orNull)
      .saslUserName(saslUserName.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.22.0-sources.jar: io/burkard/cdk/services/dms/cfnEndpoint/KafkaSettingsProperty.scala <==
package io.burkard.cdk.services.dms.cfnEndpoint

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object KafkaSettingsProperty {

  def apply(
    includeControlDetails: Option[Boolean] = None,
    includeTableAlterOperations: Option[Boolean] = None,
    noHexPrefix: Option[Boolean] = None,
    sslClientKeyArn: Option[String] = None,
    sslClientKeyPassword: Option[String] = None,
    sslCaCertificateArn: Option[String] = None,
    messageFormat: Option[String] = None,
    broker: Option[String] = None,
    securityProtocol: Option[String] = None,
    messageMaxBytes: Option[Number] = None,
    partitionIncludeSchemaTable: Option[Boolean] = None,
    includeNullAndEmpty: Option[Boolean] = None,
    includePartitionValue: Option[Boolean] = None,
    includeTransactionDetails: Option[Boolean] = None,
    topic: Option[String] = None,
    sslClientCertificateArn: Option[String] = None,
    saslPassword: Option[String] = None,
    saslUserName: Option[String] = None
  ): software.amazon.awscdk.services.dms.CfnEndpoint.KafkaSettingsProperty =
    (new software.amazon.awscdk.services.dms.CfnEndpoint.KafkaSettingsProperty.Builder)
      .includeControlDetails(includeControlDetails.map(Boolean.box).orNull)
      .includeTableAlterOperations(includeTableAlterOperations.map(Boolean.box).orNull)
      .noHexPrefix(noHexPrefix.map(Boolean.box).orNull)
      .sslClientKeyArn(sslClientKeyArn.orNull)
      .sslClientKeyPassword(sslClientKeyPassword.orNull)
      .sslCaCertificateArn(sslCaCertificateArn.orNull)
      .messageFormat(messageFormat.orNull)
      .broker(broker.orNull)
      .securityProtocol(securityProtocol.orNull)
      .messageMaxBytes(messageMaxBytes.orNull)
      .partitionIncludeSchemaTable(partitionIncludeSchemaTable.map(Boolean.box).orNull)
      .includeNullAndEmpty(includeNullAndEmpty.map(Boolean.box).orNull)
      .includePartitionValue(includePartitionValue.map(Boolean.box).orNull)
      .includeTransactionDetails(includeTransactionDetails.map(Boolean.box).orNull)
      .topic(topic.orNull)
      .sslClientCertificateArn(sslClientCertificateArn.orNull)
      .saslPassword(saslPassword.orNull)
      .saslUserName(saslUserName.orNull)
      .build()
}
